==> org.Sc.sgd.db_2.4.6.tar.gz: org.Sc.sgd.db/man/org.Sc.sgdPFAM.Rd <==
\name{org.Sc.sgdPFAM}
\alias{org.Sc.sgdPFAM}
\title{Map Entrez Gene IDs to Pfam IDs}
\description{
  org.Sc.sgdPFAM is an R object that provides mappings between an
  entrez gene identifier and the associated Pfam identifiers.
}
\details{
  Each entrez gene identifier maps to a named vector of Pfam identifiers.  The name
  for each Pfam identifier is the IPI accession numbe where this Pfam identifier is found.

  If the Pfam is a named NA, it means that the associated Entrez Gene id
  of this entrez gene identifier is found in an IPI entry of the IPI database,
  but there is no Pfam identifier in the entry.

  If the Pfam is a non-named NA, it means that the associated Entrez Gene id
  of this entrez gene identifier is not found in any IPI entry of the IPI database.

   Mappings were based on data provided by: Yeast Genome  
  ftp://genome-ftp.stanford.edu/pub/yeast/data\_download  
  With a date stamp from the source of: 2010-Sep04

}
\references{
  Kersey P. J., Duarte J., Williams A., Karavidopoulou Y., Birney E., Apweiler R.
  The International Protein Index: An integrated database for proteomics experiments.
  Proteomics 4(7): 1985-1988 (2004)
  \url{http://www.ebi.ac.uk/IPI/IPIhelp.html}
}
\examples{
        x <- org.Sc.sgdPFAM
        # Get the entrez gene identifiers that are mapped to any Pfam ID
        mapped_genes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_genes])
        # randomly display 10 genes
        sample(xx, 10)
}
\keyword{datasets}

==> org.Sc.sgd.db_2.5.0.tar.gz: org.Sc.sgd.db/man/org.Sc.sgdPFAM.Rd <==
\name{org.Sc.sgdPFAM}
\alias{org.Sc.sgdPFAM}
\title{Map Entrez Gene IDs to Pfam IDs}
\description{
  org.Sc.sgdPFAM is an R object that provides mappings between an
  entrez gene identifier and the associated Pfam identifiers.
}
\details{
  Each entrez gene identifier maps to a named vector of Pfam identifiers.  The name
  for each Pfam identifier is the IPI accession numbe where this Pfam identifier is found.

  If the Pfam is a named NA, it means that the associated Entrez Gene id
  of this entrez gene identifier is found in an IPI entry of the IPI database,
  but there is no Pfam identifier in the entry.

  If the Pfam is a non-named NA, it means that the associated Entrez Gene id
  of this entrez gene identifier is not found in any IPI entry of the IPI database.

   Mappings were based on data provided by: Yeast Genome  
  ftp://genome-ftp.stanford.edu/pub/yeast/data\_download  
  With a date stamp from the source of: 2011-Mar12

}
\references{
  Kersey P. J., Duarte J., Williams A., Karavidopoulou Y., Birney E., Apweiler R.
  The International Protein Index: An integrated database for proteomics experiments.
  Proteomics 4(7): 1985-1988 (2004)
  \url{http://www.ebi.ac.uk/IPI/IPIhelp.html}
}
\examples{
        x <- org.Sc.sgdPFAM
        # Get the entrez gene identifiers that are mapped to any Pfam ID
        mapped_genes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_genes])
        # randomly display 10 genes
        sample(xx, 10)
}
\keyword{datasets}
